@@ -5,5 +5,4 @@ Top level functions
 from pywink.api import set_bearer_token, set_wink_credentials, get_bulbs, \
     get_eggtrays, get_garage_doors, get_locks, get_powerstrip_outlets, \
     get_sensors, get_shades, get_sirens, get_switches, get_devices, \
-    is_token_set, get_subscription_key
-
+    is_token_set, get_subscription_key, get_keys
